@@ -177,14 +177,17 @@ void SystemInfoWork::activate()
         version = QString("%1%2").arg(DSysInfo::minorVersion())
                                   .arg(DSysInfo::uosEditionName());
     } else if (DSysInfo::isDeepin()) {
-        version = QString("%1 (%2)").arg(DSysInfo::uosEditionName())
-                                  .arg(DSysInfo::minorVersion());
+        QDBusConnection::systemBus().connect("com.deepin.license",
+                                             "/com/deepin/license/Info",
+                                             "com.deepin.license.Info",
+                                             "LicenseStateChange",
+                                             this, SLOT(onLicenseAuthorizationProperty()));
+
+        onLicenseAuthorizationProperty();
     } else {
         version = QString("%1 %2").arg(DSysInfo::productVersion())
                                   .arg(DSysInfo::productTypeString());
     }
-
-    m_model->setVersion(version);
     m_model->setType(QSysInfo::WordSize);
 
     if (m_systemInfo->isValid()) {
@@ -215,6 +218,32 @@ void SystemInfoWork::processChanged(QDBusMessage msg)
     }
 }
 
+void SystemInfoWork::onLicenseAuthorizationProperty()
+{
+    //获取政务授权、企业授权
+    QString authorizationProperty = "";
+    AuthorizationProperty authorizationType = static_cast<AuthorizationProperty>(getLicenseAuthorizationProperty());
+    if (AuthorizationProperty::Government == authorizationType) {
+        authorizationProperty = tr("For Government");
+    } else if (AuthorizationProperty::Enterprise == authorizationType) {
+        authorizationProperty = tr("For Enterprise");
+    }
+
+    QString version = "";
+    if (authorizationProperty != "") {
+        version = QString("%1 (%2) (%3)").arg(DSysInfo::uosEditionName())
+                .arg(authorizationProperty)
+                .arg(DSysInfo::minorVersion());
+    } else {
+        version = QString("%1 (%2)").arg(DSysInfo::uosEditionName())
+                .arg(DSysInfo::minorVersion());
+    }
+
+    if (m_model) {
+        m_model->setVersion(version);
+    }
+}
+
 void SystemInfoWork::loadGrubSettings()
 {
     if (m_dbusGrub->isValid()) {
@@ -292,6 +321,7 @@ void SystemInfoWork::onBackgroundChanged()
 
 void SystemInfoWork::setBackground(const QString &path)
 {
+#ifndef DCC_DISABLE_GRUB_THEME
     Q_EMIT requestSetAutoHideDCC(false);
 
     QDBusPendingCall call = m_dbusGrubTheme->SetBackgroundSourceFile(path);
@@ -307,6 +337,7 @@ void SystemInfoWork::setBackground(const QString &path)
 
         w->deleteLater();
     });
+#endif
 }
 
 void SystemInfoWork::showActivatorDialog()
@@ -388,6 +419,21 @@ void SystemInfoWork::getLicenseState()
     qDebug() << "authorize result:" << reply;
     m_model->setLicenseState(reply);
 }
+
+unsigned int SystemInfoWork::getLicenseAuthorizationProperty()
+{
+    QDBusInterface licenseInfo("com.deepin.license",
+                               "/com/deepin/license/Info",
+                               "com.deepin.license.Info",
+                               QDBusConnection::systemBus());
+
+    if (!licenseInfo.isValid()) {
+        qDebug() << "com.deepin.license error ," << licenseInfo.lastError().name();
+        return 0;
+    }
+
+    return licenseInfo.property("AuthorizationProperty").value<unsigned int>();
+}
 #endif
 
 }
