@@ -86,14 +86,14 @@ const QString ModuleDirectory = "/usr/lib/dde-control-center/modules";
 const QString ControlCenterIconPath = "/usr/share/icons/bloom/apps/64/preferences-system.svg";
 const QString ControlCenterGroupName = "com.deepin.dde-grand-search.group.dde-control-center-setting";
 
-static int WidgetMinimumWidth = 820;
-static int WidgetMinimumHeight = 634;
+const int WidgetMinimumWidth = 820;
+const int WidgetMinimumHeight = 634;
 
 //此处为带边距的宽度
 const int first_widget_min_width = 188;
 //此处为不带边距的宽度
-const int second_widget_min_width = 230;
-const int third_widget_min_width = 340;
+const int second_widget_min_width = 240;
+const int third_widget_min_width = 370;
 //窗口的总宽度，带边距
 const int widget_total_min_width = 820;
 //当窗口宽度大于 four_widget_min_widget 时，
@@ -305,9 +305,18 @@ void MainWindow::setPrimaryScreen(QScreen *screen)
     if(m_primaryScreen == screen)
         return;
 
+    if (m_primaryScreen)
+        m_primaryScreen->disconnect(this);
+
     m_primaryScreen = screen;
     updateWinsize();
     connect(m_primaryScreen, &QScreen::geometryChanged, this, &MainWindow::updateWinsize);
+    connect(m_primaryScreen, &QScreen::availableGeometryChanged, this, &MainWindow::updateWinsize);
+}
+
+QScreen *MainWindow::primaryScreen() const
+{
+    return m_primaryScreen.data();
 }
 
 void MainWindow::initAllModule(const QString &m)
@@ -364,7 +373,7 @@ void MainWindow::initAllModule(const QString &m)
     };
     // V20 对Deepinid 进行差异化处理  UnionID 走插件化
     if (!IsProfessionalSystem) {
-         m_modules.insert(3, {new SyncModule(this), DSysInfo::isCommunityEdition() ? "Deepin ID" : "Union ID"});
+         m_modules.insert(3, {new SyncModule(this), DSysInfo::isCommunityEdition() ? "Deepin ID" : "UOS ID"});
     }
     //读取加载一级菜单的插件
     if (InsertPlugin::instance(this, this)->updatePluginInfo("mainwindow"))
@@ -437,24 +446,33 @@ void MainWindow::updateWinsize(QRect rect)
     if (!qApp->screens().contains(m_primaryScreen))
         return;
 
+    if (this->isMaximized())
+        return;
+
+    // 取当前显示器大小
     int w = m_primaryScreen->geometry().width();
     int h = m_primaryScreen->geometry().height();
-    if (rect.width() && rect.height()) {
-        w = rect.width();
-        h = rect.height();
+
+    // 如果允许的最小宽度大于显示器宽度,则将允许的最小宽高对换下,例如1024*768分辨率并旋转90度时
+    if (WidgetMinimumWidth <= w) {
+        setMinimumSize(QSize(qMin(w, WidgetMinimumWidth), qMin(h, WidgetMinimumHeight)));
+    } else {
+        setMinimumSize(QSize(qMin(w, WidgetMinimumHeight), qMin(h, WidgetMinimumWidth)));
     }
-    WidgetMinimumWidth = qMin(w, 820);
-    WidgetMinimumHeight = qMin(h, 634);
 
-    setMinimumSize(QSize(WidgetMinimumWidth, WidgetMinimumHeight));
+    // 当前界面大小再和显示器比较大小，取其中最小的值
+    // 重新打开时会设置为上一次界面关闭时的大小,重新打开时显示器大小可能会有变化，需要比较大小避免打开的界面超出显示器
+    w = qMin(w, width());
+    h = qMin(h, height());
 
-    if (width() > WidgetMinimumWidth)
-        this->setGeometry(x(), y(), WidgetMinimumWidth, height());
-    if (height() > WidgetMinimumHeight)
-        this->setGeometry(x(), y(), width(), WidgetMinimumHeight);
+    // 设置窗口大小
+    this->setGeometry(x(), y(), w, h);
+
+    // 移动到中心位置
     this->titlebar()->updateGeometry();
     move(QPoint(m_primaryScreen->geometry().left() + (m_primaryScreen->geometry().width() - this->geometry().width()) / 2,
                 m_primaryScreen->geometry().top() + (m_primaryScreen->geometry().height() - this->geometry().height()) / 2));
+    qInfo() << "Update main window geometry: " << geometry() << ", primary screen geometry: " << m_primaryScreen->geometry();
 }
 
 void MainWindow::updateModuleVisible()
@@ -647,6 +665,8 @@ void MainWindow::setModuleSubscriptVisible(const QString &module, bool bIsDispla
             m_pair.first->setVisible(bIsDisplay);
             if (bIsDisplay) {
                 m_navModel->item(index, 0)->setData(QVariant::fromValue(QMargins(ActionIconSize + 15, 0, 0, 0)), Dtk::MarginsRole);
+                if(m_hideModuleNames.contains(module))
+                    m_navView->setRowHidden(index, true);
             } else {
                 m_navModel->item(index, 0)->setData(QVariant::fromValue(QMargins(0, 0, 0, 0)), Dtk::MarginsRole);
             }
@@ -789,7 +809,7 @@ void MainWindow::resizeEvent(QResizeEvent *event)
 
     if (m_topWidget) {
         m_topWidget->setFixedSize(event->size());
-        m_topWidget->curWidget()->setMinimumWidth(dstWidth / 2 - 40);
+        m_topWidget->curWidget()->setMinimumWidth(dstWidth / 2 - 30);
         m_topWidget->setFixedHeight(height() - this->titlebar()->height());
     }
 }
@@ -1244,7 +1264,7 @@ void FourthColWidget::initWidget(QWidget *showWidget, ModuleInterface *module)
 
     QHBoxLayout *layout = new QHBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
-    showWidget->setMinimumWidth(this->parentWidget()->width() / 2 - 40);
+    showWidget->setMinimumWidth(this->parentWidget()->width() / 2 - 30);
     showWidget->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Expanding);
     showWidget->setAutoFillBackground(true);
 
@@ -1409,3 +1429,12 @@ QString MainWindow::moduleDisplayName(const QString &module) const
     }
     return find_it->second;
 }
+
+
+bool MainWindow::event(QEvent *event)
+{
+    if(event->type() == QEvent::Show || event->type() == QEvent::Hide ){
+        Q_EMIT mainwindowStateChange(event->type());
+    }
+    return DMainWindow::event(event);
+}
