@@ -24,6 +24,8 @@
 #include "window/utils.h"
 #include "groupitem.h"
 #include "pwqualitymanager.h"
+#include "widgets/securitylevelitem.h"
+#include "securitylevelitembinder.h"
 
 #include <DFontSizeManager>
 #include <DDesktopServices>
@@ -191,7 +193,14 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
 
     QLabel *passwdLabel = new QLabel(tr("Password") + ':');
     m_passwdEdit->setAccessibleName("passwd_edit");
-    layout->addWidget(passwdLabel);
+    SecurityLevelItem *securityLevelItem  = new SecurityLevelItem(this);
+    SecurityLevelItemBinder::bind(securityLevelItem, m_passwdEdit);
+
+    QHBoxLayout *newPasswdLayout = new QHBoxLayout;
+    newPasswdLayout->addWidget(passwdLabel);
+    newPasswdLayout->addSpacing(80);
+    newPasswdLayout->addWidget(securityLevelItem);
+    layout->addLayout(newPasswdLayout);
     layout->addWidget(m_passwdEdit);
     layout->addSpacing(7);
 
@@ -245,6 +254,10 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
         m_nameEdit->lineEdit()->blockSignals(false);
     });
 
+    connect(m_nameEdit, &DLineEdit::textChanged, this, [ = ] (const QString &text) {
+        // 不想大改造，所以使用动态属性去传递数据
+        qApp->setProperty("editing_username", text);
+    });
     connect(m_nameEdit, &DLineEdit::editingFinished, this, &CreateAccountPage::checkName);
 
     connect(m_fullnameEdit, &DLineEdit::textEdited, this, [ = ](const QString &userFullName) {
@@ -266,16 +279,8 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
         }
     });
 
-    connect(m_fullnameEdit, &DLineEdit::editingFinished, this, &CreateAccountPage::checkFullname);
-
-    //失焦后就提示
-    connect(m_passwdEdit, &DLineEdit::editingFinished, this, [ = ] {
-        PwqualityManager::ERROR_TYPE error = PwqualityManager::instance()->verifyPassword(m_nameEdit->lineEdit()->text(),
-                                                                                          m_passwdEdit->lineEdit()->text());
-        if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
-            m_passwdEdit->setAlert(true);
-            m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
-        }
+    connect(m_fullnameEdit, &DLineEdit::editingFinished, this, [ = ]{
+        checkFullname();
     });
 
     //失焦后就提示，只检查密码一致性
@@ -286,7 +291,6 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
         }
     });
 
-
     connect(m_passwdEdit, &DPasswordEdit::textEdited, this, [ = ] {
         if (m_passwdEdit->isAlert()) {
             m_passwdEdit->hideAlertMessage();
@@ -378,26 +382,28 @@ void CreateAccountPage::showEvent(QShowEvent *event)
 
 void CreateAccountPage::createUser()
 {
-    bool check = false;
-    //校验输入的用户名和密码
+    // 用户名未校验通过，不需要继续往下走，直接提示
     if (!checkName()) {
-        check = true;
+        return;
     }
 
-    if (!checkFullname()) {
-        check = true;
+    //校验输入的用户名和密码
+    bool checkResult = true;
+    if (!checkFullname(checkResult)) {
+        checkResult = false;
     }
 
     bool needShowSafetyPage = false;
-    if (!checkPassword(m_repeatpasswdEdit, needShowSafetyPage)) {
-        check = true;
+    if (!checkPassword(m_repeatpasswdEdit, needShowSafetyPage, checkResult)) {
+        checkResult = false;
     }
 
-    if (!checkPassword(m_passwdEdit, needShowSafetyPage)) {
-        check = true;
+    if (!checkPassword(m_passwdEdit, needShowSafetyPage, checkResult)) {
+        checkResult = false;
     }
 
-    if (check) {
+
+    if (!checkResult) {
         if (needShowSafetyPage) {
             Q_EMIT requestCheckPwdLimitLevel();
         }
@@ -480,7 +486,6 @@ void CreateAccountPage::setCreationResult(CreationResult *result)
 bool CreateAccountPage::checkName()
 {
     const QString &userName = m_nameEdit->lineEdit()->text();
-
     if (userName.size() < 3 || userName.size() > 32) {
         m_nameEdit->setAlert(true);
         m_nameEdit->showAlertMessage(tr("Username must be between 3 and 32 characters"), m_nameEdit, 2000);
@@ -523,13 +528,14 @@ bool CreateAccountPage::checkName()
     return true;
 }
 
-bool CreateAccountPage::checkFullname()
+bool CreateAccountPage::checkFullname(bool showTips)
 {
     QString userFullName = m_fullnameEdit->lineEdit()->text();
 
     if (userFullName.size() > 32) {
         m_fullnameEdit->setAlert(true);
-        m_fullnameEdit->showAlertMessage(tr("The full name is too long"), m_fullnameEdit, 2000);
+        if(showTips)
+            m_fullnameEdit->showAlertMessage(tr("The full name is too long"), m_fullnameEdit, 2000);
         return false;
     }
 
@@ -537,8 +543,11 @@ bool CreateAccountPage::checkFullname()
     //vaild == false && code ==6 是用户名已存在
     if (!m_accountWorker->isUsernameValid(userFullName).argumentAt(0).toBool() && ErrCodeSystemUsed == m_accountWorker->isUsernameValid(userFullName).argumentAt(2).toInt()) {
         m_fullnameEdit->setAlert(true);
-        m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
-        m_fullnameEdit->lineEdit()->selectAll();
+        if(showTips){
+            m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
+            m_fullnameEdit->lineEdit()->selectAll();
+        }
+
         return false;
     }
 
@@ -548,8 +557,11 @@ bool CreateAccountPage::checkFullname()
         for (User *user : userList) {
             if (userFullName == user->fullname() || userFullName == user->name()) {
                 m_fullnameEdit->setAlert(true);
-                m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
-                m_fullnameEdit->lineEdit()->selectAll();
+                if(showTips){
+                    m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
+                    m_fullnameEdit->lineEdit()->selectAll();
+                }
+
                 return false;
             }
         }
@@ -557,8 +569,11 @@ bool CreateAccountPage::checkFullname()
         for (QString &group : groupList) {
             if (userFullName == group) {
                 m_fullnameEdit->setAlert(true);
-                m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
-                m_fullnameEdit->lineEdit()->selectAll();
+                if(showTips){
+                    m_fullnameEdit->showAlertMessage(tr("The full name has been used by other user accounts"), m_fullnameEdit, 2000);
+                    m_fullnameEdit->lineEdit()->selectAll();
+                }
+
                 return false;
             }
         }
@@ -574,12 +589,13 @@ bool CreateAccountPage::checkFullname()
     return true;
 }
 
-bool CreateAccountPage::checkPassword(DPasswordEdit *edit, bool &needShowSafetyPage)
+bool CreateAccountPage::checkPassword(DPasswordEdit *edit, bool &needShowSafetyPage, bool showTips)
 {
     if (edit == m_repeatpasswdEdit) {
         if (m_passwdEdit->lineEdit()->text() != m_repeatpasswdEdit->lineEdit()->text()) {
             m_repeatpasswdEdit->setAlert(true);
-            m_repeatpasswdEdit->showAlertMessage(tr("Passwords do not match"), this->parentWidget(), 2000);
+            if(showTips)
+                m_repeatpasswdEdit->showAlertMessage(tr("Passwords do not match"), this->parentWidget(), 2000);
             return false;
         }
     }
@@ -589,7 +605,8 @@ bool CreateAccountPage::checkPassword(DPasswordEdit *edit, bool &needShowSafetyP
 
     if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
         m_passwdEdit->setAlert(true);
-        m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
+        if(showTips)
+            m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
 
         // 企业版控制中心用户创建屏蔽安全中心登录安全的接口需求
         if ((DSysInfo::uosEditionType() == DSysInfo::UosEnterprise) || (DSysInfo::uosEditionType() == DSysInfo::UosEnterpriseC))
