@@ -25,6 +25,7 @@
 #include "../../utils.h"
 #include "createaccountpage.h"
 #include "widgets/securitylevelitem.h"
+#include  "securitylevelitembinder.h"
 
 #include "deepin_pw_check.h"
 #include "unionidbindreminderdialog.h"
@@ -37,6 +38,8 @@
 #include <QHBoxLayout>
 #include <QPushButton>
 #include <QSettings>
+#include <QLocalServer>
+#include <QLocalSocket>
 #include <QDebug>
 
 #include <unistd.h>
@@ -52,12 +55,15 @@ ModifyPasswdPage::ModifyPasswdPage(User *user, bool isCurrent, QWidget *parent)
     , m_oldPasswordEdit(new DPasswordEdit)
     , m_newPasswordEdit(new DPasswordEdit)
     , m_repeatPasswordEdit(new DPasswordEdit)
+    , m_forgetPasswordBtn(new DCommandLinkButton(tr("Forgot password?"), this))
     , m_passwordTipsEdit(new DLineEdit)
     , m_isCurrent(isCurrent)
     , m_isBindCheckError(false)
-    , m_securityLevelItem(new SecurityLevelItem(this))
+    , m_localServer(new QLocalServer(this))
 {
     initWidget();
+
+    qApp->setProperty("editing_username", m_curUser->name());
 }
 
 ModifyPasswdPage::~ModifyPasswdPage()
@@ -81,9 +87,10 @@ void ModifyPasswdPage::initWidget()
     }
     mainContentLayout->addSpacing(40);
 
+    m_forgetPasswordBtn->setVisible(false);
     if (m_isCurrent) {
         QLabel *oldPasswdLabel = new QLabel(tr("Current Password") + ":");
-        m_forgetPasswordBtn = new DCommandLinkButton(tr("Forgot password?"));
+        m_forgetPasswordBtn->setVisible(true);
         DFontSizeManager::instance()->bind(m_forgetPasswordBtn, DFontSizeManager::T8);
         m_forgetPasswordBtn->setVisible(!IsCommunitySystem && getuid() < 9999); // 如果当前账户是域账号,则屏蔽重置密码入口
         connect(m_forgetPasswordBtn, &QPushButton::clicked, this, &ModifyPasswdPage::onForgetPasswordBtnClicked);
@@ -101,10 +108,12 @@ void ModifyPasswdPage::initWidget()
     newPasswdLayout->addWidget(newPasswdLabel);
     newPasswdLayout->addSpacing(80);
 
-    newPasswdLayout->addWidget(m_securityLevelItem);
+    SecurityLevelItem *securityLevelItem = new SecurityLevelItem(this);
+    newPasswdLayout->addWidget(securityLevelItem);
     mainContentLayout->addSpacing(6);
     mainContentLayout->addLayout(newPasswdLayout);
     mainContentLayout->addWidget(m_newPasswordEdit);
+    SecurityLevelItemBinder::bind(securityLevelItem, m_newPasswordEdit);
 
     QLabel *repeatPasswdLabel = new QLabel(tr("Repeat Password") + ":");
     mainContentLayout->addSpacing(6);
@@ -169,48 +178,6 @@ void ModifyPasswdPage::initWidget()
             m_passwordTipsEdit->setAlert(false);
         }
     });
-    connect(m_newPasswordEdit, &DPasswordEdit::textChanged, this, [ = ]() {
-        if (m_newPasswordEdit->text().isEmpty()) {
-            m_securityLevelItem->setLevel(SecurityLevelItem::NoneLevel);
-            m_newPasswordEdit->setAlert(false);
-            m_newPasswordEdit->hideAlertMessage();
-            return ;
-        }
-        PASSWORD_LEVEL_TYPE m_level = PwqualityManager::instance()->GetNewPassWdLevel(m_newPasswordEdit->text());
-        PwqualityManager::ERROR_TYPE error = PwqualityManager::instance()->verifyPassword(m_newPasswordEdit->lineEdit()->text(),
-                                                                                          m_newPasswordEdit->lineEdit()->text());
-
-        if (m_level == PASSWORD_STRENGTH_LEVEL_HIGH) {
-            m_securityLevelItem->setLevel(SecurityLevelItem::HighLevel);
-            if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
-                m_newPasswordEdit->setAlert(true);
-                m_newPasswordEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_newPasswordEdit, 2000);
-            } else {
-                m_newPasswordEdit->setAlert(false);
-                m_newPasswordEdit->hideAlertMessage();
-            }
-        } else if (m_level == PASSWORD_STRENGTH_LEVEL_MIDDLE) {
-            m_securityLevelItem->setLevel(SecurityLevelItem::MidLevel);
-            if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
-                m_newPasswordEdit->setAlert(true);
-                m_newPasswordEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_newPasswordEdit, 2000);
-            } else {
-                m_newPasswordEdit->setAlert(false);
-                m_newPasswordEdit->showAlertMessage(tr("A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols"));
-            }
-        } else if (m_level == PASSWORD_STRENGTH_LEVEL_LOW) {
-            m_securityLevelItem->setLevel(SecurityLevelItem::LowLevel);
-            if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
-                m_newPasswordEdit->setAlert(true);
-                m_newPasswordEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_newPasswordEdit, 2000);
-            } else {
-                m_newPasswordEdit->setAlert(false);
-                m_newPasswordEdit->showAlertMessage(tr("A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols"), m_newPasswordEdit, 2000);
-            }
-        } else {
-            m_newPasswordEdit->showAlertMessage(tr("Error occurred when reading the configuration files of password rules!"));
-        }
-    });
 
     connect(m_repeatPasswordEdit, &DPasswordEdit::editingFinished, this, [ = ]() {
         if (m_newPasswordEdit->lineEdit()->text() != m_repeatPasswordEdit->lineEdit()->text()) {
@@ -233,6 +200,31 @@ void ModifyPasswdPage::initWidget()
     DFontSizeManager::instance()->bind(titleLabel, DFontSizeManager::T5);
 
     setFocusPolicy(Qt::StrongFocus);
+
+    if (m_isCurrent) {
+        m_localServer->setMaxPendingConnections(1);
+        m_localServer->setSocketOptions(QLocalServer::WorldAccessOption);
+        QString serverName = QString("EnableForgotButton");
+        QLocalServer::removeServer(serverName);
+        if (!m_localServer->listen(serverName)) { // 监听特定的连接
+            qWarning() << "listen failed!" << m_localServer->errorString();
+        } else {
+            qDebug() << "listen success!";
+        }
+        connect(m_localServer, &QLocalServer::newConnection, this, &ModifyPasswdPage::onNewConnection);
+
+        m_client = new QLocalSocket(this);
+        m_client->abort();
+        const QString &server = "ResetpasswordRunning";
+        m_client->connectToServer(server);
+        if(!m_client->waitForConnected(1000)) {
+            qDebug() << "connect failed, server: " << "ResetpasswordRunning " << m_client->errorString();
+            m_forgetPasswordBtn->setEnabled(true);
+        } else {
+            m_client->write("reconnect");
+            m_forgetPasswordBtn->setEnabled(false);
+        }
+    }
 }
 
 bool ModifyPasswdPage::judgeTextEmpty(DPasswordEdit *edit)
@@ -402,8 +394,6 @@ void ModifyPasswdPage::onStartResetPasswordReplied(const QString &errorText)
 {
     if (!errorText.isEmpty()) {
         m_forgetPasswordBtn->setEnabled(true);
-    } else {
-        m_enableBtnTimer.singleShot(5000, this, [this]{ m_forgetPasswordBtn->setEnabled(true); });
     }
     qDebug() << "Resetpassword reply:" << errorText;
 }
@@ -457,3 +447,16 @@ void ModifyPasswdPage::onLocalBindCheckError(const QString &error)
                                                  tips);
     }
 }
+
+void ModifyPasswdPage::onNewConnection()
+{
+    if (m_localServer->hasPendingConnections()) {
+        QLocalSocket *socket = m_localServer->nextPendingConnection();
+        connect(socket, &QLocalSocket::readyRead, this, [socket, this] {
+            auto content = socket->readAll();
+            if (content == "close") {
+                m_forgetPasswordBtn->setEnabled(true);
+            }
+        });
+    }
+}
