@@ -49,6 +49,8 @@ AddFaceInfoDialog::AddFaceInfoDialog(dcc::authentication::CharaMangerModel *mode
     initWidget();
     initConnect();
     QWidget::installEventFilter(this);
+    setAttribute(Qt::WA_ShowModal, true);
+    setFocusProxy(m_acceptBtn);
 }
 
 AddFaceInfoDialog::~AddFaceInfoDialog()
@@ -59,6 +61,7 @@ AddFaceInfoDialog::~AddFaceInfoDialog()
 void AddFaceInfoDialog::closeEvent(QCloseEvent *event)
 {
     Q_EMIT requesetCloseDlg();
+    m_faceModel->setAddButtonStatus(true);
     QDialog::closeEvent(event);
 }
 
@@ -141,7 +144,11 @@ void AddFaceInfoDialog::initConnect()
     connect(m_disclaimersItem, &DisclaimersItem::requestSetWindowEnabled, this, &AddFaceInfoDialog::onSetWindowEnabled);
     connect(m_disclaimersItem, &DisclaimersItem::requestStateChange, m_acceptBtn, &QPushButton::setDisabled);
     connect(m_cancelBtn, &QPushButton::clicked, this, &AddFaceInfoDialog::close);
-    connect(m_acceptBtn, &QPushButton::clicked, this, &AddFaceInfoDialog::requestShowFaceInfoDialog, Qt::UniqueConnection);
+    connect(m_acceptBtn, &QPushButton::clicked, this, [this](){
+        m_faceModel->setAddButtonStatus(false);
+        Q_EMIT requestShowFaceInfoDialog();
+    });
+
 }
 
 QString AddFaceInfoDialog::getFacePicture()
@@ -193,6 +200,7 @@ void AddFaceInfoDialog::responseEnrollInfoState(CharaMangerModel::AddInfoState s
         m_acceptBtn->setText(tr("Next"));
         m_acceptBtn->setDisabled(true);
         m_acceptBtn->show();
+        m_acceptBtn->setFocus();
         return;
     }
 
