@@ -52,11 +52,23 @@ using namespace DCC_NAMESPACE::bluetooth;
 DWIDGET_USE_NAMESPACE
 
 AdapterWidget::AdapterWidget(const dcc::bluetooth::Adapter *adapter, dcc::bluetooth::BluetoothModel *model)
-    : m_titleEdit(new TitleEdit)
+    : m_tip(nullptr)
+    , m_titleEdit(new TitleEdit)
     , m_adapter(adapter)
     , m_powerSwitch(new SwitchWidget(nullptr, m_titleEdit))
     , m_showAnonymousCheckBox(new DCheckBox(this))
+    , m_myDevicesGroup(nullptr)
+    , m_myDeviceListView(nullptr)
+    , m_myDeviceModel(nullptr)
+    , m_otherDevicesGroup(nullptr)
+    , m_spinner(nullptr)
+    , m_otherDeviceListView(nullptr)
+    , m_otherDeviceModel(nullptr)
+    , m_refreshBtn(nullptr)
     , m_model(model)
+    , m_discoverySwitch(nullptr)
+    , m_settingsGrp(nullptr)
+    , m_spinnerTimer(new QTimer(this))
 {
     setAccessibleName("AdapterWidget");
     m_showAnonymousCheckBox->setAccessibleName("AnonymousCheckBox");
@@ -156,13 +168,13 @@ void AdapterWidget::initUI()
     m_discoverySwitch->setFixedHeight(36);
     m_discoverySwitch->setObjectName("discoverySwitch");
 
-    SettingsGroup *settingsGrp = new SettingsGroup(nullptr, SettingsGroup::GroupBackground);
-    settingsGrp->setContentsMargins(0, 0, 0, 0);
-    settingsGrp->layout()->setMargin(0);
-    settingsGrp->setSpacing(1);
+    m_settingsGrp = new SettingsGroup(nullptr, SettingsGroup::GroupBackground);
+    m_settingsGrp->setContentsMargins(0, 0, 0, 0);
+    m_settingsGrp->layout()->setMargin(0);
+    m_settingsGrp->setSpacing(1);
 
-    settingsGrp->appendItem(m_powerSwitch);
-    settingsGrp->appendItem(m_discoverySwitch);
+    m_settingsGrp->appendItem(m_powerSwitch);
+    m_settingsGrp->appendItem(m_discoverySwitch);
 
     //~ contents_path /bluetooth/Enable Bluetooth to find nearby devices (speakers, keyboard, mouse)
     m_tip = new QLabel(tr("Enable Bluetooth to find nearby devices (speakers, keyboard, mouse)"));
@@ -203,7 +215,7 @@ void AdapterWidget::initUI()
     layout->setMargin(0);
     layout->setSpacing(10);
 
-    layout->addWidget(settingsGrp);
+    layout->addWidget(m_settingsGrp);
     layout->addWidget(m_tip, 0, Qt::AlignTop);
     layout->addSpacing(10);
     layout->addWidget(m_myDevicesGroup);
@@ -228,7 +240,9 @@ void AdapterWidget::initUI()
     m_myDeviceListView->setVisible(false);
     m_otherDeviceListView->setVisible(false);
 
-    setEnabled(!m_model->airplaneMode());
+    if (m_powerSwitch && m_powerSwitch->switchButton()) {
+        m_settingsGrp->setDisabled(m_model->airplaneMode());
+    }
 
     setLayout(layout);
 }
@@ -308,9 +322,7 @@ void AdapterWidget::initConnect()
     connect(m_model, &BluetoothModel::displaySwitchChanged, m_showAnonymousCheckBox, &DCheckBox::setChecked);
     connect(m_showAnonymousCheckBox, &DCheckBox::stateChanged, this, [ = ](int state) {
         if (state == Qt::CheckState::Unchecked) {
-            if (m_model->displaySwitch()) {
-                Q_EMIT requestSetDisplaySwitch(false);
-            }
+            Q_EMIT requestSetDisplaySwitch(false);
             // 将蓝牙名称为空的设备过滤掉
             for (int i = 0; i < m_deviceLists.size(); i++) {
                 DeviceSettingsItem *pDeviceItem = m_deviceLists[i];
@@ -327,9 +339,7 @@ void AdapterWidget::initConnect()
                 }
             }
         } else {
-            if (!m_model->displaySwitch()) {
-                Q_EMIT requestSetDisplaySwitch(true);
-            }
+            Q_EMIT requestSetDisplaySwitch(true);
             // 显示所有蓝牙设备
             for (int i = 0; i < m_deviceLists.size(); i++) {
                 DeviceSettingsItem *pDeviceItem = m_deviceLists[i];
@@ -347,7 +357,9 @@ void AdapterWidget::initConnect()
         }
     });
 
-    connect(m_model, &BluetoothModel::airplaneEnableChanged, this, &AdapterWidget::setDisabled);
+    if (m_powerSwitch && m_powerSwitch->switchButton()) {
+        connect(m_model, &BluetoothModel::airplaneEnableChanged, m_settingsGrp, &dcc::widgets::SettingsGroup::setDisabled);
+    }
 }
 
 void AdapterWidget::loadDetailPage()
@@ -363,12 +375,39 @@ void AdapterWidget::setAdapter(const Adapter *adapter)
     connect(adapter, &Adapter::deviceRemoved, this, &AdapterWidget::removeDevice, Qt::QueuedConnection);
     connect(adapter, &Adapter::poweredChanged, this, &AdapterWidget::onPowerStatus, Qt::QueuedConnection);
     connect(m_model, &BluetoothModel::adpaterPowerChanged, m_powerSwitch, [ = ] {
-        m_powerSwitch->switchButton()->setEnabled(true);
-        m_spinnerBtn->hide();
+        QTimer::singleShot(100, this, [this] {
+            m_powerSwitch->switchButton()->setEnabled(true);
+            m_spinnerBtn->hide();
+            if (m_spinnerTimer && m_spinnerTimer->isActive()) {
+                m_spinnerTimer->stop();
+            }
+        });
     });
     connect(adapter, &Adapter::loadStatus, m_powerSwitch, [ = ] {
-        m_powerSwitch->switchButton()->setEnabled(false);
-        m_spinnerBtn->show();
+        QTimer::singleShot(100, this, [this] {
+            m_powerSwitch->switchButton()->setEnabled(false);
+            m_spinnerBtn->show();
+            if (m_spinnerTimer) {
+                if (!m_spinnerTimer->isActive()) {
+                    m_spinnerTimer->start(6 * 1000);
+                } else {
+                    //重新计时
+                    m_spinnerTimer->stop();
+                    m_spinnerTimer->start(6 * 1000);
+                }
+            }
+        });
+    });
+
+    connect(m_spinnerTimer, &QTimer::timeout, this, [this]() {
+        if (m_powerSwitch &&  m_powerSwitch->switchButton() &&
+                !m_powerSwitch->switchButton()->isEnabled() &&
+                !m_spinnerBtn->isHidden()) {
+            qWarning() << " switch bluetooth status timeout";
+            m_powerSwitch->switchButton()->setEnabled(true);
+            m_spinnerBtn->hide();
+            m_spinnerTimer->stop();
+        }
     });
 
     m_titleEdit->setTitle(adapter->name());
