@@ -123,7 +123,7 @@ CommonInfoWork::CommonInfoWork(CommonInfoModel *model, QObject *parent)
         if (msgcode == "1001") {
             in3 = tr("Failed to get root access");
         } else if (msgcode == "1002") {
-            in3 = tr("Please sign in to your Union ID first");
+            in3 = tr("Please sign in to your UOS ID first");
         } else if (msgcode == "1003") {
             in3 = tr("Cannot read your PC information");
         } else if (msgcode == "1004") {
