@@ -103,13 +103,6 @@ void SystemNotifyWidget::initUI()
     m_itemLockScreen->setTitle(tr("When the screen is locked"));
     m_settingsGrp->appendItem(m_itemLockScreen);
     mainLayout->addWidget(m_settingsGrp);
-
-    //~ contents_path /notification/System Notifications
-    //~ child_page System Notifications
-    m_btnShowInDock = new SwitchWidget(tr("Show icon on Dock"));
-    m_btnShowInDock->addBackground();
-    m_btnShowInDock->layout()->setContentsMargins(10, 0, 10, 0);
-    mainLayout->addWidget(m_btnShowInDock);
     mainLayout->addStretch();
 
     m_settingsGrp->setVisible(m_btnDisturbMode->isChecked());
@@ -123,10 +116,7 @@ void SystemNotifyWidget::initConnect()
     });
     m_btnDisturbMode->setChecked(m_model->isDisturbMode());
     m_settingsGrp->setVisible(m_model->isDisturbMode());
-    connect(m_model, &SysItemModel::showInDockChanged, this, [this](bool state) {
-        m_btnShowInDock->setChecked(state);
-    });
-    m_btnShowInDock->setChecked(m_model->isShowInDock());
+
     connect(m_model, &SysItemModel::timeSlotChanged, this, [this](bool state) {
         m_itemTimeSlot->setState(state);
     });
@@ -149,9 +139,6 @@ void SystemNotifyWidget::initConnect()
         m_settingsGrp->setVisible(state);
         Q_EMIT requestSetSysSetting(SysItemModel::DNDMODE, state);
     });
-    connect(m_btnShowInDock, &SwitchWidget::checkedChanged, this, [ = ](bool state) {
-        Q_EMIT requestSetSysSetting(SysItemModel::SHOWICON, state);
-    });
     connect(m_itemTimeSlot, &TimeSlotItem::stateChanged, this, [ = ](bool state) {
         Q_EMIT requestSetSysSetting(SysItemModel::OPENBYTIMEINTERVAL, state);
     });
