@@ -121,19 +121,21 @@ void SoundModule::initSearchData()
 
     auto func_input_changed = [ = ]() {
         bool bSoundInput = func_is_visible("soundInput");
+        bool bVirtualInput = (m_inputPortCount == 0 && m_inputPortEnableCount > 0);
         m_frameProxy->setWidgetVisible(module, input, bSoundInput);
-        m_frameProxy->setDetailVisible(module, input, tr("Input Device"), bSoundInput);
+        m_frameProxy->setDetailVisible(module, input, tr("Input Device"), bSoundInput && !bVirtualInput);
         //输入设备为空不显示
         bool isInputVisble = m_inputPortEnableCount > 0;
-        m_frameProxy->setDetailVisible(module, input, tr("Automatic Noise Suppression"), bSoundInput && func_is_visible("soundNoiseReduce", "Hidden") && isInputVisble);
+        m_frameProxy->setDetailVisible(module, input, tr("Automatic Noise Suppression"), bSoundInput && func_is_visible("soundNoiseReduce", "Hidden") && isInputVisble && m_model->reduceNoise());
         m_frameProxy->setDetailVisible(module, input, tr("Input Volume"), bSoundInput && func_is_visible("soundInputSlider", "Hidden") && isInputVisble);
         m_frameProxy->setDetailVisible(module, input, tr("Input Level"), bSoundInput && isInputVisble);
     };
 
     auto func_output_changed = [ = ]() {
         bool bSoundOutput = func_is_visible("soundOutput");
+        bool bVirtualOutput = (m_outputPortCount == 0 && m_outputPortEnableCount > 0);
         m_frameProxy->setWidgetVisible(module, output, bSoundOutput);
-        m_frameProxy->setDetailVisible(module, output, tr("Output Device"), bSoundOutput);
+        m_frameProxy->setDetailVisible(module, output, tr("Output Device"), bSoundOutput && !bVirtualOutput);
         bool isBlueModeVisible = false;
         for (const Port* port : m_model->ports())
         {
@@ -196,6 +198,21 @@ void SoundModule::initSearchData()
         m_frameProxy->updateSearchData(module);
     });
 
+    connect(m_model, &SoundModel::reduceNoiseChanged, this, [ = ]() {
+        func_process_all();
+        m_frameProxy->updateSearchData(module);
+    });
+
+    connect(m_model, &SoundModel::speakerNameChanged, this, [ = ]() {
+        func_process_all();
+        m_frameProxy->updateSearchData(module);
+    });
+
+    connect(m_model, &SoundModel::microphoneNameChanged, this, [ = ]() {
+        func_process_all();
+        m_frameProxy->updateSearchData(module);
+    });
+
     connect(GSettingWatcher::instance(), &GSettingWatcher::notifyGSettingsChanged, this, [=](const QString &gsetting, const QString &state) {
         if ("" == gsetting || !gsettingsMap.contains(gsetting)) {
             return;
@@ -268,6 +285,14 @@ void SoundModule::getPortCount()
                 m_inputPortEnableCount ++;
         }
     }
+
+    // 云平台搜索支持
+    if (m_outputPortEnableCount == 0 && !m_model->speakerName().startsWith("auto_null")) {
+        m_outputPortEnableCount++;
+    }
+    if (m_inputPortEnableCount == 0 && !m_model->microphoneName().startsWith("auto_null") && !m_model->microphoneName().endsWith("monitor")) {
+        m_inputPortEnableCount++;
+    }
 }
 
 void SoundModule::initialize()
@@ -300,9 +325,29 @@ void SoundModule::active()
         m_soundWidget->showDefaultWidget();
     });
 
+    // 有端口时显示设备管理
+    connect(m_model, &SoundModel::portAdded, m_soundWidget, [ this ]() {
+        if (!m_model->ports().isEmpty()) {
+            m_soundWidget->setSubItemHidden("deviceManage", false);
+        }
+    });
+
+    // 无端口时关闭设备管理
+    connect(m_model, &SoundModel::portRemoved, m_soundWidget, [ this ]() {
+        if (m_model->ports().isEmpty()) {
+            m_soundWidget->setSubItemHidden("deviceManage", true);
+        }
+    });
+
     m_frameProxy->pushWidget(this, m_soundWidget);
     m_soundWidget->setVisible(true);
     m_soundWidget->showDefaultWidget();
+
+    // 无端口时不显示设备管理
+    if (m_model->ports().isEmpty()) {
+        m_soundWidget->setSubItemHidden("deviceManage", true);
+    }
+
 }
 
 int SoundModule::load(const QString &path)
