@@ -158,6 +158,10 @@ void SpeakerPage::setModel(dcc::sound::SoundModel *model)
         m_mute = flag;
         refreshIcon();
     });
+    connect(m_model, &SoundModel::speakerNameChanged, this, [ this ](const QString &name) {
+        m_speakerName = name;
+        showDevice();
+    });
 
     initSlider();
     initCombox();
@@ -234,11 +238,28 @@ void SpeakerPage::changeBluetoothMode(const int idx)
 void SpeakerPage::refreshActivePortShow(const dcc::sound::Port *port)
 {
     if (port && port->isActive()) {
-        m_outputSoundCbx->comboBox()->setCurrentText(port->name() + "(" + port->cardName() + ")");
+        // 端口激活和未激活时，carname内容不一致，此时无法通过settext匹配选择项，改为通过查找id来匹配
+        for (int i = 0; i < m_outputSoundCbx->comboBox()->count(); i++) {
+            auto tmpPort = m_outputModel->item(i)->data(Qt::WhatsThisPropertyRole).value<const dcc::sound::Port *>();
+
+            if (tmpPort != nullptr && tmpPort->id() == port->id() && tmpPort->cardName() ==  port->cardName()) {
+                m_outputSoundCbx->comboBox()->blockSignals(true);
+                m_outputSoundCbx->comboBox()->setCurrentIndex(i);
+                m_outputSoundCbx->comboBox()->blockSignals(false);
+                break;
+            }
+        }
+
         setBlueModeVisible(port->isBluetoothPort() && (m_outputModel->rowCount() > 0));
+    } else {
+        setBlueModeVisible(false);
     }
 }
 
+bool SpeakerPage::hasVirtualSink() {
+    return m_model->ports().isEmpty() && !m_speakerName.startsWith("auto_null");
+}
+
 void SpeakerPage::addPort(const dcc::sound::Port *port)
 {
     if (dcc::sound::Port::Out == port->direction()) {
@@ -248,7 +269,11 @@ void SpeakerPage::addPort(const dcc::sound::Port *port)
         pi->setData(QVariant::fromValue<const dcc::sound::Port *>(port), Qt::WhatsThisPropertyRole);
 
         connect(port, &dcc::sound::Port::nameChanged, this, [ = ](const QString str) {
-            pi->setText(str);
+            pi->setText(str + "(" + port->cardName() + ")");
+        });
+
+        connect(port, &dcc::sound::Port::cardNameChanged, this, [ = ](const QString str) {
+            pi->setText(port->name() + "(" + str + ")");
         });
 
         connect(port, &dcc::sound::Port::isOutputActiveChanged, this, [ = ](bool isActive) {
@@ -472,9 +497,10 @@ void SpeakerPage::refreshIcon()
 
 void SpeakerPage::showWaitSoundPortStatus(bool showStatus)
 {
-    if ((m_currentPort && !m_currentPort->isBluetoothPort()) || m_model->currentBluetoothAudioMode().isEmpty()) {
+    if (!m_currentPort || !m_currentPort->isBluetoothPort() || m_model->currentBluetoothAudioMode().isEmpty()) {
         m_blueSoundCbx->setVisible(false);
     }
+
     m_outputSoundCbx->setEnabled(showStatus);
     m_blueSoundCbx->setEnabled(showStatus);
 }
@@ -490,11 +516,17 @@ void SpeakerPage::showDevice()
     if (!m_speakSlider || !m_vbWidget || !m_balanceSlider || !m_outputSlider)
         return;
 
-    if (1 > m_outputModel->rowCount()){
+    // 支持云平台无端口设备的显示
+    if (1 > m_outputModel->rowCount() && !hasVirtualSink()){
         setDeviceVisible(false);
         setBlueModeVisible(false);
     } else
         setDeviceVisible(true);
+
+    // 云平台关闭输出设备和蓝牙模式
+    m_outputSoundCbx->setVisible(!hasVirtualSink());
+    if (hasVirtualSink())
+        m_blueSoundCbx->setVisible(false);
 }
 
 void SpeakerPage::setDeviceVisible(bool visible)
